@@ -1,10 +1,14 @@
 from .display_metrics_callback import DisplayMetricsCallback
 from .lr_logger import LrLogger
+from .epoch_num_logger import EpochNumLogger
+from .epoch_time_logger import EpochTimeLogger
 from .nil_callback import NilCallback
 from .earlystop_lr import EarlyStoppingLR
 
 __all__ = [
     "LrLogger",
+    "EpochNumLogger",
+    "EpochTimeLogger",
     "NilCallback",
     "DisplayMetricsCallback",
     "EarlyStoppingLR",
