@@ -3,6 +3,7 @@ from .inception import InceptionModule
 from .mlp import MLP
 from .residual import ResidualModule, ResidualBlock
 from .transformer import TransformerEncoderBlock, TransformerEncoder
+from .gated_conv import GatedConv
 
 __all__ = [
     "DenseBlock",
@@ -10,5 +11,6 @@ __all__ = [
     "MLP",
     "ResidualBlock",
     "ResidualModule",
-    "TransformerEncoderBlock"
+    "TransformerEncoderBlock",
+    "GatedConv",
 ]
